@@ -14,14 +14,19 @@ import pathlib
 import math
 import uuid
 
-from logging import INFO, WARNING
+from logging import DEBUG
+
+from typing import cast
+
 
 import numpy as np
 import json
 
 import astropy.time
 
-from sdsstools import read_yaml_file
+from sdsstools import get_logger, read_yaml_file
+from sdsstools.logger import SDSSLogger
+from sdsstools.logger import StreamFormatter  
 
 from clu import AMQPClient, CommandStatus
 from clu.model import Model
@@ -33,6 +38,11 @@ from basecam.mixins import CoolerMixIn, ExposureTypeMixIn, ImageAreaMixIn, Shutt
 from basecam.notifier import EventListener
 from basecam.utils import cancel_task
 
+from lvmtipo.site import Site
+from lvmtipo.siderostat import Siderostat
+from lvmtipo.fiber import Fiber
+from lvmtipo.target import Target
+
 from skymakercam.params import load as params_load
 from cluplus.proxy import Proxy, ProxyPartialInvokeException, invoke, unpack
 
@@ -44,11 +54,6 @@ from skymakercam.starimage import find_guide_stars, make_synthetic_image
 __all__ = ['SkymakerCameraSystem', 'SkymakerCamera']
 
 
-#import re
-#def to_camel_case(text):
-    #return re.sub('[.](.)', lambda x: x.group(1).upper(), text.capitalize())
-
-
 def rebin(arr, bin):
     new_shape=[int(arr.shape[0]/bin), int(arr.shape[1]/bin)]
     shape = (new_shape[0], arr.shape[0] // new_shape[0],
@@ -79,20 +84,12 @@ class SkymakerCameraSystem(CameraSystem):
     from skymakercam import __version__
 #    __version__ = "0.0.138"
 
-    def __init__(self, camera_class=None, camera_config=None,
-                 include=None, exclude=None, logger=None,
-                 log_header=None, log_file=None, verbose=False, ip_list=None):
-        super().__init__(camera_class=camera_class, camera_config=camera_config,
-                         include=include, exclude=exclude, logger=logger, log_header=log_header,
-                         log_file=log_file, verbose=verbose)
-
-
     def list_available_cameras(self):
         """ Gather skymaker camera uids.
         :return: a list of cameras.
         :rtype: list
         """
-
+        print("c")
         return [c.camera_params.get("uid") for c in self.cameras]
 
 
@@ -100,7 +97,6 @@ class SkymakerCamera(
     BaseCamera,
     ExposureTypeMixIn,
     ShutterMixIn,
-    CoolerMixIn,
     ImageAreaMixIn,
 ):
     """A virtual camera that does not require hardware.
@@ -124,6 +120,10 @@ class SkymakerCamera(
 
         super().__init__(*args, **kwargs)
 
+        self.logger.sh.setLevel(DEBUG)
+        self.logger.sh.formatter = StreamFormatter(fmt='%(asctime)s %(name)s %(levelname)s %(filename)s:%(lineno)d: \033[1m%(message)s\033[21m') 
+        self.logger.debug("construct")
+
         self.config = kwargs['camera_params']
         self.inst_params = params_load(f"skymakercam.params.{self.config_get('instpar', None)}")
         self.inst_params.catalog_path = os.path.expandvars(self.config_get('catalog_path', tempfile.TemporaryDirectory()))
@@ -131,7 +131,9 @@ class SkymakerCamera(
             self.log(f"Creating catalog path: {self.inst_params.catalog_path}", WARNING)
             pathlib.Path(self.inst_params.catalog_path).mkdir(parents=True, exist_ok=True)
 
-        self.amqpc = AMQPClient(name=f"{sys.argv[0]}.proxy-{uuid.uuid4().hex[:8]}")
+        rmqname = f"proxy-{uuid.uuid4().hex[:8]}"
+        self.logger.debug(rmqname)
+        self.amqpc = AMQPClient(name=rmqname)
 
         self._tcs = Proxy(self.amqpc, self.config_get('tcs', None))
         
@@ -152,6 +154,10 @@ class SkymakerCamera(
         self._kmirror = Proxy(self.amqpc, self.config_get('kmirror', None))
         self.kmirror_angle = 0.
         
+        self.site = self.config_get('site', "LCO")
+        self.sid = Siderostat()
+        self.geoloc = Site(name = self.site)
+
         self._shutter_position = False
 
         self.temperature = 25
@@ -177,20 +183,27 @@ class SkymakerCamera(
 
 
     async def _connect_internal(self, **connection_params):
-        self.log(f"connecting ...")
+        self.logger.debug(f"connecting ...")
+        
         await self.amqpc.start()
         await self._tcs.start()
         await self._focus_stage.start()
         await self._kmirror.start()
 
         self.tcs_coord, self.tcs_pa = await self.tcs_get_position_j2000()
-        
+
+        self.logger.debug(f"{self.tcs_coord}")
+
         return True
 
     async def _disconnect_internal(self):
         """Close connection to camera.
         """
-        await amqpc.stop()
+        self.logger.debug("disconnect")
+        await self._tcs.client.stop()
+        await self._focus_stage.client.stop()
+        await self._kmirror.client.stop()
+        await self.amqpc.stop()
 
     def _status_internal(self):
         return {"temperature": self.temperature, "cooler": 10.0}
@@ -215,13 +228,20 @@ class SkymakerCamera(
         self.log(f"kmirror angle (deg): {self.kmirror_angle}")
 
         tcs_coord_current, self.tcs_pa = await self.tcs_get_position_j2000()
+        
+        mathar_angle = math.degrees(self.sid.fieldAngle(self.geoloc, Target(tcs_coord_current), None))
+        self.log(f"mathar angle (deg): {mathar_angle}")
+
+        sky_angle = self.kmirror_angle - mathar_angle
+        self.log(f"sky angle (deg): {sky_angle}")
+
         separation = self.tcs_coord.separation(tcs_coord_current)
         self.log(f"separation {separation.arcminute }")
         if separation.arcminute > 18 or not self.guide_stars:
             self.tcs_coord = tcs_coord_current
-            self.guide_stars = find_guide_stars(self.tcs_coord, np.deg2rad(self.kmirror_angle), self.inst_params, remote_catalog=True)
+            self.guide_stars = find_guide_stars(self.tcs_coord, np.deg2rad(sky_angle), self.inst_params, remote_catalog=True)
         else:    
-            self.guide_stars = find_guide_stars(tcs_coord_current, np.deg2rad(self.kmirror_angle), self.inst_params, remote_catalog=False, cull_cat=False)
+            self.guide_stars = find_guide_stars(tcs_coord_current, np.deg2rad(sky_angle), self.inst_params, remote_catalog=False, cull_cat=False)
             
         return make_synthetic_image(chip_x=self.guide_stars.chip_xxs,
                                     chip_y=self.guide_stars.chip_yys,
